@@ -8,10 +8,7 @@ class Profiles:
     file_config = yaml.load(open('profile.yaml'), Loader=yaml.FullLoader)['django']
     APP_NAME = file_config['application']['name']
     PROFILE = file_config['profiles']['active']
-    if PROFILE == 'dev':
-        ENVIRONMENTS = f'.environments/asn_dev.yml'
-    else:
-        ENVIRONMENTS = f'.environments/{APP_NAME}_{PROFILE}.yml'
+    ENVIRONMENTS = f'.environments/{APP_NAME}_{PROFILE}.yml'
     APPLICATION = file_config['application']
     CONFIG = {}
     env = {}
